==> pinta-2.0.2.tar.gz: pinta-2.0.2/Pinta.Core/Managers/ResourceManager.cs <==
// 
// ResourceManager.cs
//  
// Author:
//       Jonathan Pobst <monkey@jpobst.com>
// 
// Copyright (c) 2010 Jonathan Pobst
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.IO;
using Pinta.Resources;

namespace Pinta
{
	public interface IResourceService
	{
		Gdk.Pixbuf GetIcon (string name);
		Gdk.Pixbuf GetIcon (string name, int size);
		Stream? GetResourceIconStream (string name);
	}

	public class ResourceManager : IResourceService
	{
		public Gdk.Pixbuf GetIcon (string name)
		{
			return GetIcon (name, 16);
		}

		public Gdk.Pixbuf GetIcon (string name, int size)
		{
			return ResourceLoader.GetIcon (name, size);
		}

		public Stream? GetResourceIconStream (string name)
		{
			return ResourceLoader.GetResourceIconStream (name);
		}
	}
}

==> pinta-3.0.1.tar.gz: pinta-3.0.1/Pinta.Core/Managers/ResourceManager.cs <==
// 
// ResourceManager.cs
//  
// Author:
//       Jonathan Pobst <monkey@jpobst.com>
// 
// Copyright (c) 2010 Jonathan Pobst
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using Pinta.Resources;

namespace Pinta;

public interface IResourceService
{
	Gdk.Texture GetIcon (string name);
	Gdk.Texture GetIcon (string name, int size);
}

public sealed class ResourceManager : IResourceService
{
	public Gdk.Texture GetIcon (string name)
	{
		return GetIcon (name, 16);
	}

	public Gdk.Texture GetIcon (string name, int size)
	{
		return ResourceLoader.GetIcon (name, size);
	}
}
